@@ -67,11 +67,14 @@ render_book = function(
   if (length(input) == 1L && dir_exists(input)) {
     message(sprintf("Rendering book in directory '%s'", input))
     owd = setwd(input); on.exit(setwd(owd), add = TRUE)
-    input = "index.Rmd"
+    # if a directory is passed, we assume that index.Rmd exists
+    input = get_index_file()
+    # No input file to use as fallback
+    if (is_empty(input)) input = NULL
+  } else {
+    stop_if_not_exists(input)
   }
 
-  stop_if_not_exists(input)
-
   format = NULL  # latex or html
   if (is.list(output_format)) {
     format = output_format$bookdown_output_format
@@ -79,11 +82,13 @@ render_book = function(
   } else if (is.null(output_format) || is.character(output_format)) {
     if (is.null(output_format) || identical(output_format, 'all')) {
       # formats can safely be guess when considering index.Rmd and its expected frontmatter
-      # and not another Rmd file which has no expected YAML frontmatter
-      stop_if_not_exists("index.Rmd")
-      all_formats = rmarkdown::all_output_formats("index.Rmd")
-      # when no format provided, return name of the first resolved
-      output_format = if (is.null(output_format)) all_formats[[1]] else all_formats
+      # As a fallback we assumes input could have the YAML, otherwise we just use gitbook();
+      # Also, when no format provided, return name of the first resolved
+      output_format = get_output_formats(
+        fallback_format = "bookdown::gitbook",
+        first = is.null(output_format),
+        fallback_index = input
+      )
     }
     if (length(output_format) > 1) return(unlist(lapply(output_format, function(fmt)
       xfun::Rscript_call(render_book, list(
@@ -205,7 +210,7 @@ render_new_session = function(files, main, config, output_format, clean, envir,
   for (i in which(grepl('[.]md$', files) & files != files_md))
     file.copy(files[i], files_md[i], overwrite = TRUE)
   # if input is index.Rmd or not preview mode, compile all Rmd's
-  rerun = !opts$get('preview') || identical(opts$get('input_rmd'), 'index.Rmd')
+  rerun = !opts$get('preview') || opts$get('input_rmd') %in% get_index_file()
   if (!rerun) rerun = files %in% opts$get('input_rmd')
   add1 = merge_chapter_script(config, 'before')
   add2 = merge_chapter_script(config, 'after')
